@@ -82,12 +82,24 @@ class ClassificationMultiLabelEvaluator(EvaluatorBase):
             y_score = np.array(prediction_distribution_list),
             class_name_list = self.am.classnames
         )
+        p_at_r_100 = ClassifierEvalMultilabel.compute_p_at_r(            
+            y_true  = np.array(annotation_distribution_list),
+            y_score = np.array(prediction_distribution_list),
+            class_name_list = self.am.classnames,
+            recall_thresh=1
+        )
         p_at_r_99 = ClassifierEvalMultilabel.compute_p_at_r(            
             y_true  = np.array(annotation_distribution_list),
             y_score = np.array(prediction_distribution_list),
             class_name_list = self.am.classnames,
             recall_thresh=0.99
         )
+        p_at_r_95 = ClassifierEvalMultilabel.compute_p_at_r(            
+            y_true  = np.array(annotation_distribution_list),
+            y_score = np.array(prediction_distribution_list),
+            class_name_list = self.am.classnames,
+            recall_thresh=0.95
+        )
         thr_at_p_99 = ClassifierEvalMultilabel.get_threshold_at_p(            
             y_true  = np.array(annotation_distribution_list),
             y_score = np.array(prediction_distribution_list),
@@ -101,6 +113,8 @@ class ClassificationMultiLabelEvaluator(EvaluatorBase):
                 'ap': ap_dict[key],
                 'inflection': inflection_info[key],
                 'p_at_r_99': p_at_r_99[key],
+                'p_at_r_100': p_at_r_100[key],
+                'p_at_r_95': p_at_r_95[key],
                 'thr_at_p_99': thr_at_p_99[key]
             }
             ap_info[key] = res_dict
