@@ -2,14 +2,11 @@ import re
 import cv2
 import sys
 import cv2 as cv
-from matplotlib.patches import Polygon
-from mtutils.utils_vvd.box_processing import get_xyxy
 import numpy as np
 import PIL.Image as Image
 
 import matplotlib
 import matplotlib.pyplot as plt
-import math
 
 from .utils import is_number, vvd_round
 from .utils import is_path_obj
@@ -32,6 +29,7 @@ from .array_processing import get_Several_MinMax_Array
 
 popular_image_suffixes = ['png', 'jpg', 'jpeg', 'bmp']
 
+
 def show_hist(img):
     rows, cols = img.shape
     hist = img.reshape(rows * cols)
@@ -43,6 +41,23 @@ def show_hist(img):
     return histogram
 
 
+def get_center_bbox(input_image, width, height):
+    assert width > 0 and height > 0
+    H, W = input_image.shape[:2]
+    center_x, center_y = W / 2, H / 2
+    x_min = vvd_round(center_x - width / 2)
+    x_max = vvd_round(x_min + width)
+    y_min = vvd_round(center_y - height / 2)
+    y_max = vvd_round(y_min + height)
+    crop_box = [x_min, y_min, x_max, y_max]
+    return crop_box
+
+
+def center_crop(input_image, width, height):
+    crop_box = get_center_bbox(input_image, width, height)
+    return crop_data_around_boxes(input_image, crop_box)
+
+
 def image_resize(img_source, shape=None, factor=None, unique_check=False, interpolation=None):
     image_H, image_W = img_source.shape[:2]
     if shape is not None:
@@ -100,6 +115,35 @@ def to_gray_image(img):
     else:
         raise RuntimeError(f"unknown data type {type(img)}")
 
+def percentile_normalize(image, low_value, low_p, high_value, high_p, except_zero=True):
+    assert low_value < high_value
+    assert 0 <= low_p < high_p <= 100
+
+    if str(image.dtype) == 'uint8':
+        if except_zero:
+            min_value = np.percentile(image[image!=0], low_p)
+            max_value = np.percentile(image[image!=0], high_p)
+        else:
+            min_value = np.percentile(image, low_p)
+            max_value = np.percentile(image, high_p)
+
+        if max_value <= min_value:
+            return image
+
+        a = (high_value - low_value) / (max_value - min_value)
+        b = low_value - a * min_value
+
+        normed_image = np.clip(image.astype('float32') * a + b, 0, 255).astype('uint8')
+        return normed_image
+    else:
+        print(f"percentile_normalize neet uint8 image as input img.")
+        return image
+
+def gaussian_mask_2d(size, sigma):
+    gaussian_mask_1d = cv2.getGaussianKernel(size, sigma)
+    gaussian_mask_2d = gaussian_mask_1d * gaussian_mask_1d.T
+    normalized_gaussian_mask_2d = min_max_normalize(gaussian_mask_2d)
+    return normalized_gaussian_mask_2d
 
 def min_max_normalize(image, min=0, max=1, min_p=0, max_p=100):
     assert 0 <= min_p < max_p <= 100, f"0 <= min_p {min_p} < max_p {max_p}<= 100 should be true." 
@@ -228,6 +272,38 @@ def img_rotate(img,
     return rotated
 
 
+def image_flip_lr(image):
+    return np.fliplr(image)
+
+
+def image_flip_ud(image):
+    return np.flipud(image)
+
+def image_rotate_90(image, contiguousarray=True):
+    (h, w) = image.shape[:2]
+    M = cv2.getRotationMatrix2D((w / 2, h/2), 90, 1.0)
+    rotated = cv2.warpAffine(image, M, (w, h))
+    if contiguousarray:
+        rotated = np.ascontiguousarray(rotated)
+    return rotated
+
+def image_rotate_180(image, contiguousarray=True):
+    (h, w) = image.shape[:2]
+    M = cv2.getRotationMatrix2D((w / 2, h/2), 180, 1.0)
+    rotated = cv2.warpAffine(image, M, (w, h))
+    if contiguousarray:
+        rotated = np.ascontiguousarray(rotated)
+    return rotated
+
+def image_rotate_270(image, contiguousarray=True):
+    (h, w) = image.shape[:2]
+    M = cv2.getRotationMatrix2D((w / 2, h/2), 270, 1.0)
+    rotated = cv2.warpAffine(image, M, (w, h))
+    if contiguousarray:
+        rotated = np.ascontiguousarray(rotated)
+    return rotated
+
+
 def cv_rgb_imread(image_path, gray=False):
     """
     按照RGB顺序使用cv读取图像
