@@ -385,9 +385,9 @@ def get_file_hash_code(file):
 
 class MyEncoder(json.JSONEncoder):
     """
-    自定义序列化方法，解决 TypeError - Object of type xxx is not JSON serializable 错误
+    自定义序列化方法, 解决 TypeError - Object of type xxx is not JSON serializable 错误
     使用方法:
-    在json.dump时加入到cls中即可，例如:
+    在json.dump时加入到cls中即可, 例如:
     json.dumps(data, cls=MyEncoder) 
     """
 
@@ -497,7 +497,7 @@ def log_init(log_path, quiet=False, level=logging.INFO):
         # open log file as  mode of write
         open_type = 'w'
 
-    # basicConfig 无法解决中文乱码的问题，封存相关代码
+    # basicConfig 无法解决中文乱码的问题, 封存相关代码
     # 据说 Python 3.9 之后会加入basicConfig() 的encoding和errors关键字配置
     # logging.basicConfig(
     #     # 日志级别,logging.DEBUG,logging.ERROR
@@ -520,6 +520,11 @@ def log_init(log_path, quiet=False, level=logging.INFO):
     # file handler 
     handler = logging.FileHandler(log_file_path, mode=open_type, encoding='utf-8')
     handler.setFormatter(logging.Formatter("%(asctime)s-%(name)s-%(levelname)s: %(message)s"))
+
+    for old_handler in logger.handlers[::-1]:
+        old_handler.stream.close()
+        logger.removeHandler(old_handler)
+
     logger.addHandler(handler)
 
     if quiet:
@@ -552,6 +557,8 @@ def dir_check(dir_path, verbose=False):
     """
 
     dir_path = str(dir_path)
+    if dir_path == '':
+        return True
     assert isinstance(dir_path, str)
     dir_path = uniform_split_char(dir_path)
     if not os.path.isdir(dir_path):
@@ -638,7 +645,7 @@ def time_stamp():
 
 
 def smart_copy(source_file_path, target_path, verbose=False, remove_source_file=False, overwrite=False):
-    """[复制文件从源到目标，如果目标已经存在则跳过]]
+    """[复制文件从源到目标, 如果目标已经存在则跳过]]
 
     Args:
         source_file_path ([str]): [源文件路径]
@@ -709,7 +716,7 @@ def json_save(json_dict, json_path, overwrite=False, verbose=False):
 
 def glob_recursively(path, extension, recursively=True):
     """
-    在path 路径中递归查找所有扩展名为extension的文件，返回完整路径名列表
+    在path 路径中递归查找所有扩展名为extension的文件, 返回完整路径名列表
     """
     path = str(path)
     if recursively:
@@ -720,35 +727,35 @@ def glob_recursively(path, extension, recursively=True):
 
 def is_integer(num):
     """
-    是否是整数，返回bool结果
+    是否是整数, 返回bool结果
     """
     return isinstance(num, (int, np.int, np.int32, np.uint8, np.int16, np.int64, np.intc))
 
 
 def is_float(num):
     """
-    是否是浮点数，返回bool结果
+    是否是浮点数, 返回bool结果
     """
     return isinstance(num, (float, np.floating))
 
 
 def is_number(num):
     """
-    是否是数字，返回bool结果
+    是否是数字, 返回bool结果
     """
     return is_float(num) or is_integer(num)
 
 
 def is_bool(data):
     """
-    是否是 bool 值，返回bool结果
+    是否是 bool 值, 返回bool结果
     """
     return isinstance(data, bool) or isinstance(data, np.bool_)
 
 
 def whether_divisible_by(to_be_divided, dividing):
     """
-    to_be_divided 是否可以被 dividing 整除，返回bool结果
+    to_be_divided 是否可以被 dividing 整除, 返回bool结果
     """
     assert is_integer(to_be_divided) and is_integer(dividing)
     if to_be_divided % dividing == 0:
@@ -1359,6 +1366,22 @@ def remove_file(path):
             os.remove(path)
 
 
+def display_class_property(class_def, verbose=False):
+    """Display Configuration values."""
+    if verbose:
+        print("\n")
+        print("Configurations:")
+    property_dict = dict()
+    for property in dir(class_def):
+        if not property.startswith("__") and not callable(getattr(class_def, property)):
+            property_dict[property] = getattr(class_def, property)
+            if verbose:
+                print("{:50} {}".format(property, getattr(class_def, property)))
+    if verbose:
+        print("\n")
+    return property_dict
+
+
 if __name__ == '__main__':
     LOD = ListOrderedDict()
     LOD['a'] = 'a content'
